@@ -1343,6 +1343,70 @@ ALTER TABLE talks ALTER state TYPE talkstate_new USING(state::varchar)::talkstat
 ALTER TABLE talks ALTER state SET DEFAULT 'waiting_for_files';
 DROP TYPE talkstate;
 ALTER TYPE talkstate_new RENAME TO talkstate;
+-- 31 up
+CREATE TYPE talkstate_new AS ENUM (
+    'waiting_for_files',
+    'cutting',
+    'generating_previews',
+    'notification',
+    'preview',
+    'transcoding',
+    'fixuping',
+    'uploading',
+    'publishing',
+    'notify_final',
+    'finalreview',
+    'announcing',
+    'transcribing',
+    'syncing',
+    'done',
+    'injecting',
+    'remove',
+    'removing',
+    'broken',
+    'needs_work',
+    'lost',
+    'ignored',
+    'uninteresting'
+);
+ALTER TABLE talks ALTER state DROP DEFAULT;
+ALTER TABLE talks ALTER state TYPE talkstate_new USING(state::varchar)::talkstate_new;
+ALTER TABLE talks ALTER state SET DEFAULT 'waiting_for_files';
+DROP TYPE talkstate;
+ALTER TYPE talkstate_new RENAME TO talkstate;
+-- 31 down
+CREATE TYPE talkstate_new AS ENUM (
+    'waiting_for_files',
+    'cutting',
+    'generating_previews',
+    'notification',
+    'preview',
+    'transcoding',
+    'fixuping',
+    'uploading',
+    'publishing',
+    'notify_final',
+    'finalreview',
+    'announcing',
+    'done',
+    'injecting',
+    'remove',
+    'removing',
+    'broken',
+    'needs_work',
+    'lost',
+    'ignored',
+    'uninteresting'
+);
+ALTER TABLE talks ALTER state DROP DEFAULT;
+ALTER TABLE talks ALTER state TYPE talkstate_new USING(state::varchar)::talkstate_new;
+ALTER TABLE talks ALTER state SET DEFAULT 'waiting_for_files';
+DROP TYPE talkstate;
+ALTER TYPE talkstate_new RENAME TO talkstate;
+-- 32 up
+ALTER TABLE talks ADD extra_data JSONB;
+-- 32 down
+ALTER TABLE talks DROP extra_data;
 @@ code
 -- 1 up
 CREATE VIEW last_room_files AS
@@ -2063,3 +2127,30 @@ CREATE VIEW talk_list AS
      LEFT JOIN talks ON rooms.id = talks.room
      LEFT JOIN events ON talks.event = events.id
      LEFT JOIN tracks ON talks.track = tracks.id;
+-- 9 down
+DROP VIEW mailers;
+CREATE VIEW mailers AS
+ SELECT speakers.email,
+    talks.nonce,
+    talks.title
+   FROM speakers_talks
+     JOIN speakers ON speakers_talks.speaker = speakers.id
+     JOIN talks ON speakers_talks.talk = talks.id
+  WHERE speakers.email IS NOT NULL;
+-- 9 up
+DROP VIEW mailers;
+CREATE VIEW mailers AS
+ SELECT speakers.email,
+    talks.nonce,
+    talks.title
+   FROM speakers_talks
+     JOIN speakers ON speakers_talks.speaker = speakers.id
+     JOIN talks ON speakers_talks.talk = talks.id
+  WHERE speakers.email IS NOT NULL
+ UNION
+ SELECT tracks.email,
+    talks.nonce,
+    talks.title
+   FROM talks
+     JOIN tracks ON talks.track = tracks.id
+  WHERE tracks.email IS NOT NULL;
